// Copyright © Bending Spoons Group. All rights reserved.

import Foundation

/// This struct has the responsability create an error message for a particular error.
public struct ErrorMessageComposer {
  /// Returns the message for the provided error.
  public let messageFor: (_ error: Error) -> String

  /// Call as function the `messageFor` property.
  public func callAsFunction(for error: Error) -> String {
    self.messageFor(error)
  }
}

extension ErrorMessageComposer {
  /// Return a message that begins with a list of people tagged
  /// - Parameter tags: The list of handles to tag in the message.
  /// - Returns: The message to send
  public static func live(tags: [String]) -> Self {
    .init { error in
      """
      \(tags.map { "@\($0)" }.joined(separator: ", "))
      FingerPullRequest encountered an error:
      \(error.localizedDescription)
      """
    }
  }
}
