// Copyright © Bending Spoons Group. All rights reserved.

import Foundation

/// Github handler
public struct Github {
  /// Returns a `PullRequest` instance for the PR number provided.
  public let fetchPullRequest: (_ number: Int) throws -> PullRequest
}

extension Github {
  /// Live implementation of a Github instance
  /// - Parameters:
  ///   - network: The network client
  ///   - repository: The repository must be in the form `User/RepoName` ex: `BendingSpoons/splice-ios-swift`
  ///   - authToken: Github authorization token
  /// - Returns: The live implementation
  static func live(
    network: Network,
    repository: String,
    authToken: String
  ) -> Self {
    .init(fetchPullRequest: { prNumber in
      let data = try network.get(
        url: URL(string: "https://api.github.com/repos/\(repository)/pulls/\(prNumber)")!,
        headers: ["Authorization": "token \(authToken)"]
      )
      let decoder = JSONDecoder()
      decoder.dateDecodingStrategy = .iso8601
      let pullRequest = try decoder.decode(PullRequest.self, from: data)
      return pullRequest
    })
  }
}
