// Copyright © Bending Spoons Group. All rights reserved.

import Foundation

/// Describes which PRs must be selected.
public enum PullRequestSelectionStrategy {
  /// Select merged pull requests
  case merged(MergedPullRequestSelectionStrategy)

  /// Select pull requests with specific numbers.
  case select([Int])
}

/// Describes which merged PRs must be selected.
public enum MergedPullRequestSelectionStrategy {
  /// Get the most recently merged PRs.
  case recently(limit: UInt)

  /// Get all the PRs after a specific date.
  /// - Note: The time is not considered.
  case after(date: Date)

  /// Get all the merged PRs until a specific commit message is found.
  /// If the commit mesage is not present in the `git log` it will be returned just the most recent merge.
  /// - Note: Remember to escape any special character in the `commitMessage`
  case until(commitMessage: String)
}
