// Copyright © Bending Spoons Group. All rights reserved.

import Foundation

extension String {
  /// Helper that decodes a `String` into a type `D`
  /// - Parameter to: the desired type `D`
  /// - Throws: if the decoding fails
  /// - Returns: The decoded version of the `String`
  public func decoded<D: Decodable>(to _: D.Type) throws -> D {
    let data = self.data(using: .utf8)!
    return try data.decoded(to: D.self)
  }
}

extension Data {
  /// Helper to decode a Decodable from JSON Data
  public func decoded<D: Decodable>(to _: D.Type, jsonDecoderBuilder: () -> JSONDecoder = { .init() }) throws -> D {
    do {
      return try jsonDecoderBuilder().decode(D.self, from: self)
    } catch {
      print(error)
      throw error
    }
  }
}

// MARK: - Decoding helper

extension Encodable {
  /// Helper to encode an Encodable to a JSON String.
  /// The `prettyPrinted` and `sortedKeys` output formatting options are used.
  public func prettyJsonEncoded() throws -> String {
    let jsonEncoder = JSONEncoder()
    jsonEncoder.outputFormatting = [.prettyPrinted, .sortedKeys]

    let jsonData = try jsonEncoder.encode(self)
    guard let decodedData = String(data: jsonData, encoding: .utf8) else {
      fatalError("Can't decode JSON data")
    }
    return decodedData
  }
}
