// Copyright © Bending Spoons Group. All rights reserved.

import Foundation

extension Array {
  /// Unwraps an array of results with the following strategy:
  /// - If there are `Failure`s, it throws all of them wrapped in an `Errors` struct
  /// - If there are no errors, it returns all the `Success`es
  public func getSuccessesOrThrow<Success, Failure: Error>() throws -> [Success] where Element == Result<Success, Failure> {
    var successes: [Success] = []
    var failures: [Failure] = []

    for result in self {
      switch result {
      case .success(let success):
        successes.append(success)
      case .failure(let failure):
        failures.append(failure)
      }
    }

    guard failures.isEmpty else {
      throw Errors(errors: failures)
    }

    return successes
  }
}
