// Copyright © Bending Spoons Group. All rights reserved.

import Foundation

/// Thread safe wrapper around an object.
public final class ThreadSafe<A> {
  private var wrapped: A
  private let queue = DispatchQueue(label: "ThreadSafe")

  /// Default initializer
  public init(_ value: A) {
    self.wrapped = value
  }

  /// The object value
  public var value: A {
    return self.queue.sync { self.wrapped }
  }

  /// It allows to read and modify the value athomically
  /// - Parameter transform: the transform closure with the changes to apply t the value
  public func atomically(_ transform: (inout A) -> Void) {
    self.queue.sync {
      transform(&self.wrapped)
    }
  }
}
