// Copyright © Bending Spoons Group. All rights reserved.

import Foundation
import Logging
@testable import FingerPullRequest

extension Shell {
  /// Mock implementation that always calls a closure which defaults to a fatalError
  static func unimplemented(
    execute: @escaping (
      String, [String: EnvironmentValue], Logger.Level, Logger.Level, URL?, Bool
    ) -> Result = { _, _, _, _, _, _ in fatalError() }
  ) -> Shell {
    .init(_execute: execute)
  }
}

extension Shell.Result {
  /// Mock successful result.
  static func success(output: String = "") -> Self {
    .init(status: 0, output: output, error: "")
  }

  /// Mock failure result.
  static func failure(status: Int32 = 1, output: String = "", error: String = "") -> Self {
    .init(status: status, output: output, error: error)
  }
}
