// Copyright © Bending Spoons Group. All rights reserved.

import Foundation
import XCTest

/// It tries to execute the `expression` and we expect it to `throw` an error of type `E`.
///
/// - Parameters:
///   - expression: a function that should throw an `error`.
///   - expectedError: the `error` we expect to obtain from the `expression`.
///   - message: a custom error `message`.
///   - file: the `file` in which the assertion has been invoked
///   - line: the `line` in which the assertion has been invoked
public func XCTAssertThrowsError<T, E: Equatable & Error>(
  _ expression: @autoclosure () throws -> T,
  expectedError: E,
  _ message: @autoclosure () -> String = "",
  fail: (String, StaticString, UInt) -> Void = { XCTFail($0, file: $1, line: $2) },
  file: StaticString = #filePath,
  line: UInt = #line
) {
  do {
    _ = try expression()
    XCTFail("Function should throws\n\(message())", file: file, line: line)
  } catch {
    guard let err = error as? E else {
      fail("Thrown error is of type \(type(of: error)) instead of \(type(of: expectedError))\n\(message())", file, line)
      return
    }
    XCTAssertEqual(err, expectedError, file: file, line: line)
  }
}
