// Copyright © Bending Spoons Group. All rights reserved.

import ArgumentParser
import FingerPullRequest
import Foundation

extension Main {
  struct UpdateChangelog: ParsableCommand {
    static var configuration = CommandConfiguration(
      commandName: "changelog",
      abstract: "Update `Changelog.md` file"
    )

    mutating func run() throws {
      let fingerPullRequest = try FingerPullRequest.live(
        errorReporterSlackChannel: "",
        repositoryName: Main.repositoryName
      )

      try fingerPullRequest.updateChangelog(file: .init(fileURLWithPath: "../../CHANGELOG.md")) { pr in
        print("Execute UpdateChangelog on: \(pr.number)")
        return Self.formattedChangelogEntry(
          prNumber: pr.number,
          entry: pr.title
        )
      }
    }
  }
}

extension Main.UpdateChangelog {
  static func gitHubPRLink(number: Int) -> String {
    "[#\(number)](https://github.com/\(Main.repositoryName)/pull/\(number))"
  }

  static func formattedChangelogEntry(
    prNumber: Int,
    entry: String
  ) -> String {
    [entry, Self.gitHubPRLink(number: prNumber)].joined(separator: " ")
  }
}
