#!/bin/bash

# Define the path to the ProjectInformation.json file
PROJECT_INFO_PATH=".winston/ProjectInformation.json"

# Check if the ProjectInformation.json file exists
if [ ! -f "$PROJECT_INFO_PATH" ]; then
  echo "Error: ProjectInformation.json file not found in .winston directory."
  exit 1
fi

# Extract and store the values of "buildNumber" and "version" keys from the "mainTarget" object
read -r buildNumber version <<< $(awk -F'[:,]' '/"mainTarget"/ { getline; while ($1 !~ /^}/) { if ($1 ~ /"buildNumber"/ || $1 ~ /"version"/) {gsub(/[ \t]/, "", $2); print $2} getline } }' "$PROJECT_INFO_PATH")

# Define the path to the project.pbxproj file
PBXPROJ_FILE="Camera Calculator.xcodeproj/project.pbxproj"

# Check if the project.pbxproj file exists
if [ ! -f "$PBXPROJ_FILE" ]; then
  echo "Error: project.pbxproj file not found."
  exit 1
fi

# Define the search patterns and replacement values
BUILD_NUMBER_PATTERN='APP_BUILD = ([0-9]+|"[0-9]+");'
VERSION_PATTERN='APP_VERSION = ([0-9.]+|"[0-9.]+");'

# Count the number of lines containing "APP_BUILD" but not containing "$(APP_BUILD)"
build_count=$(grep -c 'APP_BUILD' "$PBXPROJ_FILE" | grep -vc '$(APP_BUILD)')

# Count the number of lines containing "APP_VERSION" but not containing "$(APP_VERSION)"
version_count=$(grep -c 'APP_VERSION' "$PBXPROJ_FILE" | grep -vc '$(APP_VERSION)')

# Replace the build number if found
old_build_numbers=$(grep 'APP_BUILD' "$PBXPROJ_FILE" | grep -o '[0-9]\+' | head -n 4)
for old_build_number in $old_build_numbers; do
  sed -i '' -E "s/${BUILD_NUMBER_PATTERN}/APP_BUILD = ${buildNumber};/" "$PBXPROJ_FILE"
done

# Replace the version if found
old_versions=$(grep 'APP_VERSION' "$PBXPROJ_FILE" | grep -o '[0-9.]\+' | head -n 4)
for old_version in $old_versions; do
  sed -i '' -E "s/${VERSION_PATTERN}/APP_VERSION = ${version};/" "$PBXPROJ_FILE"
done

echo "Successfully replaced APP_BUILD and APP_VERSION in Project"
exit 0
